@@ -9,12 +9,12 @@ import yaml
 import os.path
 
 import logging
-logger = logging.getLogger(__name__)
+#logger = logging.getLogger(__name__)
 
 sutra_list = []
 sutra_dict = {}
 
-f = open(os.path.join(os.path.dirname(__file__), "sutras.yaml"), "r")
+f = open(os.path.join(os.path.dirname(__file__), "sutras.yaml"), "r", encoding="utf-8")
 y = yaml.load(f, Loader=yaml.FullLoader)
 sutra_dict = process_yaml(y)
 sutra_list = sutra_dict.values()
